[longomatch] Rename KeepCommonTags to KeepGenericTags.



commit 8b447e3407462f8092ed477a0559491cb583b84d
Author: Julien Moutte <julien fluendo com>
Date:   Wed Apr 15 19:05:01 2015 +0200

    Rename KeepCommonTags to KeepGenericTags.
    
    Indeed Common tags can be misunderstood to tags in common between both ends of the link when this just 
means that generic tags should be maintained in the resulting event or not.

 LongoMatch.Core/Store/ActionLink.cs            |    6 +++---
 LongoMatch.GUI/Gui/Component/LinkProperties.cs |    4 ++--
 Tests/Core/Store/TestActionLink.cs             |    4 ++--
 3 files changed, 7 insertions(+), 7 deletions(-)
---
diff --git a/LongoMatch.GUI/Gui/Component/LinkProperties.cs b/LongoMatch.GUI/Gui/Component/LinkProperties.cs
index 3705ee1..729de3a 100644
--- a/LongoMatch.GUI/Gui/Component/LinkProperties.cs
+++ b/LongoMatch.GUI/Gui/Component/LinkProperties.cs
@@ -32,7 +32,7 @@ namespace LongoMatch.Gui.Component
                                Edited = true;
                        };
                        checkbuttonkeepcommontags.Toggled += (sender, e) => {
-                               link.KeepCommonTags = checkbuttonkeepcommontags.Active;
+                               link.KeepGenericTags = checkbuttonkeepcommontags.Active;
                                Edited = true;
                        };
                }
@@ -77,7 +77,7 @@ namespace LongoMatch.Gui.Component
 
                                comboboxteamaction.Active = (int)link.TeamAction;
                                checkbuttonkeepplayertags.Active = link.KeepPlayerTags;
-                               checkbuttonkeepcommontags.Active = link.KeepCommonTags;
+                               checkbuttonkeepcommontags.Active = link.KeepGenericTags;
                        }
                }
        }
diff --git a/Tests/Core/Store/TestActionLink.cs b/Tests/Core/Store/TestActionLink.cs
index c561d3d..44edd6e 100644
--- a/Tests/Core/Store/TestActionLink.cs
+++ b/Tests/Core/Store/TestActionLink.cs
@@ -36,7 +36,7 @@ namespace Tests.Core.Store
                        link.DestinationTags = new List<Tag> { new Tag ("tag2") };
                        link.Action = LinkAction.Toggle;
                        link.TeamAction = TeamLinkAction.Invert;
-                       link.KeepCommonTags = false;
+                       link.KeepGenericTags = false;
                        link.KeepPlayerTags = false;
                        return link;
                }
@@ -55,7 +55,7 @@ namespace Tests.Core.Store
                        Assert.AreEqual (link.DestinationTags, link2.DestinationTags);
                        Assert.AreEqual (link.Action, link2.Action);
                        Assert.AreEqual (link.TeamAction, link2.TeamAction);
-                       Assert.AreEqual (link.KeepCommonTags, link2.KeepCommonTags);
+                       Assert.AreEqual (link.KeepGenericTags, link2.KeepGenericTags);
                        Assert.AreEqual (link.KeepPlayerTags, link2.KeepPlayerTags);
                }
 


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/LongoMatch.Core/Store/ActionLink.cs b/LongoMatch.Core/Store/ActionLink.cs
index a9375dc..881c9aa 100644
--- a/LongoMatch.Core/Store/ActionLink.cs
+++ b/LongoMatch.Core/Store/ActionLink.cs
@@ -31,7 +31,7 @@ namespace LongoMatch.Core.Store
        {
                public ActionLink ()
                {
-                       KeepCommonTags = true;
+                       KeepGenericTags = true;
                        KeepPlayerTags = true;
                        TeamAction = TeamLinkAction.Keep;
                        SourceTags = new List<Tag> ();
@@ -96,9 +96,9 @@ namespace LongoMatch.Core.Store
                }
 
                /// <summary>
                /// If <c>true</c>, common tags will be copied
                /// </summary>
-               public bool KeepCommonTags {
+               public bool KeepGenericTags {
                        get;
                        set;
                }
@@ -96,9 +96,9 @@ namespace LongoMatch.Core.Store
 
                /// <summary>
-               /// If <c>true</c>, common tags will be copied
+               /// If <c>true</c>, generic tags will be copied.
                /// </summary>